==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/WebFieldValidationStateDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridValidationStateDescriptionMetadata } from "./WebGridValidationStateDescriptionMetadata";
import { WebFieldValidationStateDescription } from "./WebFieldValidationStateDescription";
/**
 * @hidden
 */
var WebFieldValidationStateDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebFieldValidationStateDescriptionMetadata, _super);
    function WebFieldValidationStateDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebFieldValidationStateDescriptionMetadata.b = function (a) {
        if (WebFieldValidationStateDescriptionMetadata.a == null) {
            WebFieldValidationStateDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebFieldValidationStateDescriptionMetadata.c(WebFieldValidationStateDescriptionMetadata.a);
        }
        if (a.j(WebFieldValidationStateDescriptionMetadata.a)) {
            return;
        }
        a.y(WebFieldValidationStateDescriptionMetadata.a);
    };
    WebFieldValidationStateDescriptionMetadata.c = function (a) {
        WebGridValidationStateDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:FieldValidationState");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
        a.item("Field", "String");
    };
    WebFieldValidationStateDescriptionMetadata.d = function (a) {
        WebFieldValidationStateDescriptionMetadata.b(a);
        a.aa("WebFieldValidationState", function () { return new WebFieldValidationStateDescription(); });
        a.z("WebFieldValidationState", WebFieldValidationStateDescriptionMetadata.a);
    };
    WebFieldValidationStateDescriptionMetadata.$t = markType(WebFieldValidationStateDescriptionMetadata, 'WebFieldValidationStateDescriptionMetadata');
    WebFieldValidationStateDescriptionMetadata.a = null;
    return WebFieldValidationStateDescriptionMetadata;
}(Base));
export { WebFieldValidationStateDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebFieldValidationStateDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridValidationStateDescriptionMetadata } from "./WebGridValidationStateDescriptionMetadata";
import { WebFieldValidationStateDescription } from "./WebFieldValidationStateDescription";
/**
 * @hidden
 */
var WebFieldValidationStateDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebFieldValidationStateDescriptionMetadata, _super);
    function WebFieldValidationStateDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebFieldValidationStateDescriptionMetadata.b = function (a) {
        if (WebFieldValidationStateDescriptionMetadata.a == null) {
            WebFieldValidationStateDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebFieldValidationStateDescriptionMetadata.c(WebFieldValidationStateDescriptionMetadata.a);
        }
        if (a.k(WebFieldValidationStateDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebFieldValidationStateDescriptionMetadata.a);
    };
    WebFieldValidationStateDescriptionMetadata.c = function (a) {
        WebGridValidationStateDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:FieldValidationState");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        if (a.containsKey("__skipSuffix")) {
            a.removeItem("__skipSuffix");
        }
        a.item("Field", "String");
    };
    WebFieldValidationStateDescriptionMetadata.d = function (a) {
        WebFieldValidationStateDescriptionMetadata.b(a);
        a.ac("WebFieldValidationState", function () { return new WebFieldValidationStateDescription(); });
        a.ab("WebFieldValidationState", WebFieldValidationStateDescriptionMetadata.a);
    };
    WebFieldValidationStateDescriptionMetadata.$t = markType(WebFieldValidationStateDescriptionMetadata, 'WebFieldValidationStateDescriptionMetadata');
    WebFieldValidationStateDescriptionMetadata.a = null;
    return WebFieldValidationStateDescriptionMetadata;
}(Base));
export { WebFieldValidationStateDescriptionMetadata };
